package tablecloth-native

  1. Overview
  2. Docs

Source file TableclothContainer.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
(** This module contains module signatures which are used in functions which
    accept first class modules.
*)

module type Sum = sig
  (** Modules which conform to this signature can be used with functions like
      {!Array.sum} or {!List.sum}
  *)

  type t

  val zero : t

  val add : t -> t -> t
end